--- loncom/interface/lonhtmlcommon.pm 2012/11/30 11:28:51 1.335
+++ loncom/interface/lonhtmlcommon.pm 2013/01/03 20:02:12 1.340
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# a pile of common html routines
#
-# $Id: lonhtmlcommon.pm,v 1.335 2012/11/30 11:28:51 bisitz Exp $
+# $Id: lonhtmlcommon.pm,v 1.340 2013/01/03 20:02:12 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -1396,7 +1396,8 @@ sub htmlareaselectactive {
# is used to determine when the countdown timer turns red to warn the user
# to think about submitting.
- my $dueDateLayout = &mt('Due in: {dn} {dl} {hnn}{sep}{mnn}{sep}{snn} [_1]',"");
+ my $dueDateLayout = &mt('Due in: {dn} {dl} {hnn}{sep}{mnn}{sep}{snn} [_1]',
+ "");
my $early = '- '.&mt('Submit Early').'';
my $pastdue = '- '.&mt('Past Due').'';
$output .= < "LC_breadcrumbs" }) unless ($CourseBreadcrumbs) ;
- &render_advtools(\$links);
+ my $nav_and_tools = 0;
+ foreach my $item ('navigation','tools') {
+ if (ref($tools{$item}) eq 'ARRAY') {
+ $nav_and_tools += scalar(@{$tools{$item}})
+ }
+ }
+ if (($links ne '') || ($nav_and_tools)) {
+ &render_tools(\$links);
+ $links = &htmltag('div', $links,
+ { id => "LC_breadcrumbs" }) unless ($CourseBreadcrumbs) ;
+ }
+ my $adv_tools = 0;
+ if (ref($tools{'advtools'}) eq 'ARRAY') {
+ $adv_tools = scalar(@{$tools{'advtools'}});
+ }
+ if (($links ne '') || ($adv_tools)) {
+ &render_advtools(\$links);
+ }
# Return the @Crumbs stack to what we started with
push(@Crumbs,$last);
@@ -1895,12 +1909,9 @@ returns: nothing
sub docs_breadcrumbs {
my ($allowed,$crstype,$contenteditor,$title,$precleared)=@_;
my ($folderpath,@folders);
- if ($env{'form.pagepath'}) {
- @folders = split('&',$env{'form.pagepath'});
- } else {
- @folders = split('&',$env{'form.folderpath'});
- }
+ @folders = split('&',$env{'form.folderpath'});
my $plain='';
+ my $container = 'sequence';
my ($randompick,$isencrypted,$ishidden,$is_random_order) = (-1,0,0,0);
my @docs_crumbs;
while (@folders) {
@@ -1916,9 +1927,9 @@ sub docs_breadcrumbs {
}
$url .= &escape($folderpath);
my $name=&unescape($foldername);
-# each of randompick number, hidden, encrypted, random order are
-# appended with ":"s to the foldername
- $name=~s/\:(\d*)\:(\w*)\:(\w*):(\d*)$//;
+# each of randompick number, hidden, encrypted, random order, is_page
+# are appended with ":"s to the foldername
+ $name=~s/\:(\d*)\:(\w*)\:(\w*):(\d*)\:?(\d*)$//;
if ($contenteditor) {
if ($1 ne '') {
$randompick=$1;
@@ -1928,6 +1939,7 @@ sub docs_breadcrumbs {
if ($2) { $ishidden=1; }
if ($3) { $isencrypted=1; }
if ($4 ne '') { $is_random_order = 1; }
+ if ($5 == 1) {$container = 'page'; }
}
if ($folder eq 'supplemental') {
$name = &mt('Supplemental '.$crstype.' Contents');
@@ -1964,7 +1976,7 @@ sub docs_breadcrumbs {
return (&breadcrumbs(undef,undef,$menulink,'nohelp',undef,undef,
$contenteditor),
$randompick,$ishidden,$isencrypted,$plain,
- $is_random_order);
+ $is_random_order,$container);
} else {
return \@docs_crumbs;
}
@@ -3027,7 +3039,10 @@ PARAMSONE
}
if ((chkh == 1) || (listwchange)) {
var primaryheight = document.getElementById('LC_nav_bar').offsetHeight;
- var secondaryheight = document.getElementById('LC_secondary_menu').offsetHeight;
+ var secondaryheight;
+ if (document.getElementById('LC_secondary_menu') != null) {
+ secondaryheight = document.getElementById('LC_secondary_menu').offsetHeight;
+ }
var crumbsheight = document.getElementById('LC_breadcrumbs').offsetHeight;
var dccidheight = 0;
if (document.getElementById('dccid') != null) {
@@ -3118,7 +3133,7 @@ ENDUTILITY
sub jump_to_editres {
my ($cfile,$home,$switchserver,$forceedit,$forcereg,$symb,$folderpath,
- $title,$idx,$suppurl) = @_;
+ $title,$idx,$suppurl,$todocs) = @_;
my $jscall;
if ($switchserver) {
if ($home) {
@@ -3162,6 +3177,9 @@ sub jump_to_editres {
if ($forcereg) {
$cfile .= (($cfile=~/\?/)?'&':'?').'register=1';
}
+ if ($todocs) {
+ $cfile .= (($cfile=~/\?/)?'&':'?').'todocs=1';
+ }
}
$jscall = "go('$cfile')";
}